GO_analyse() function on an RNAseq experiment.
AlvMac_results = GO_analyse(eSet=AlvMac, f="Treatment")
applied to the toy input data AlvMac.
data(AlvMac_results)GO contains a table ranking all GO terms related to genes in
the expression dataset based on the average ability of their related
genes to cluster the samples according to the predefined grouping
factor.
mapping contains the table mapping genes present in the
dataset to GO terms.
genes contains a table ranking all genes present in the
expression dataset based on their ability to cluster the samples
according to the predefined grouping factor (see 'factor' below).
factor contains the grouping factor analysed.
method contains the statistical framework used.
subset contains the filters used to select a subset of
samples from the original ExpressionSet for analysis.
rank.by contains the metric used to rank the scoring tables.
ntree contains number of trees built during the randomForest
analysis.
mtry contains the number of features randomly sampled as
candidates at each split in each tree built during the randomForest
analysis.
set.seed() function prior
to running any randomising or sampling function.data(AlvMac_results)
str(AlvMac_results)
head(AlvMac_results$GO, n=20)
head(AlvMac_results$GO$genes, n=20)
Run the code above in your browser using DataLab